==> syncope-2.1.2-source-release.zip: syncope-2.1.2/ext/flowable/common-lib/src/main/java/org/apache/syncope/common/lib/types/FlowableEntitlement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.types;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.Collections;
import java.util.Set;
import java.util.TreeSet;

public final class FlowableEntitlement {

    public static final String BPMN_PROCESS_LIST = "BPMN_PROCESS_LIST";

    public static final String BPMN_PROCESS_GET = "BPMN_PROCESS_GET";

    public static final String BPMN_PROCESS_SET = "BPMN_PROCESS_SET";

    public static final String BPMN_PROCESS_DELETE = "BPMN_PROCESS_DELETE";

    public static final String WORKFLOW_TASK_LIST = "WORKFLOW_TASK_LIST";

    public static final String USER_REQUEST_LIST = "USER_REQUEST_LIST";

    public static final String USER_REQUEST_FORM_LIST = "USER_REQUEST_FORM_LIST";

    public static final String USER_REQUEST_FORM_CLAIM = "USER_REQUEST_FORM_CLAIM";

    public static final String USER_REQUEST_FORM_SUBMIT = "USER_REQUEST_FORM_SUBMIT";

    public static final String USER_REQUEST_START = "USER_REQUEST_START";

    public static final String USER_REQUEST_CANCEL = "USER_REQUEST_CANCEL";

    private static final Set<String> VALUES;

    static {
        Set<String> values = new TreeSet<>();
        for (Field field : FlowableEntitlement.class.getDeclaredFields()) {
            if (Modifier.isStatic(field.getModifiers()) && String.class.equals(field.getType())) {
                values.add(field.getName());
            }
        }
        VALUES = Collections.unmodifiableSet(values);
    }

    public static Set<String> values() {
        return VALUES;
    }

    private FlowableEntitlement() {
        // private constructor for static utility class
    }
}

==> syncope-3.0.14-source-release.zip: syncope-3.0.14/ext/flowable/common-lib/src/main/java/org/apache/syncope/common/lib/types/FlowableEntitlement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.types;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.Collections;
import java.util.Set;
import java.util.TreeSet;

public final class FlowableEntitlement {

    public static final String BPMN_PROCESS_GET = "BPMN_PROCESS_GET";

    public static final String BPMN_PROCESS_SET = "BPMN_PROCESS_SET";

    public static final String BPMN_PROCESS_DELETE = "BPMN_PROCESS_DELETE";

    public static final String WORKFLOW_TASK_LIST = "WORKFLOW_TASK_LIST";

    public static final String USER_REQUEST_LIST = "USER_REQUEST_LIST";

    public static final String USER_REQUEST_FORM_LIST = "USER_REQUEST_FORM_LIST";

    public static final String USER_REQUEST_FORM_CLAIM = "USER_REQUEST_FORM_CLAIM";

    public static final String USER_REQUEST_FORM_UNCLAIM = "USER_REQUEST_FORM_UNCLAIM";

    public static final String USER_REQUEST_FORM_SUBMIT = "USER_REQUEST_FORM_SUBMIT";

    public static final String USER_REQUEST_START = "USER_REQUEST_START";

    public static final String USER_REQUEST_CANCEL = "USER_REQUEST_CANCEL";

    private static final Set<String> VALUES;

    static {
        Set<String> values = new TreeSet<>();
        for (Field field : FlowableEntitlement.class.getDeclaredFields()) {
            if (Modifier.isStatic(field.getModifiers()) && String.class.equals(field.getType())) {
                values.add(field.getName());
            }
        }
        VALUES = Collections.unmodifiableSet(values);
    }

    public static Set<String> values() {
        return VALUES;
    }

    private FlowableEntitlement() {
        // private constructor for static utility class
    }
}
